@@ -1,8 +1,8 @@
 from typing import List, TypeVar
 
-from statham.dsl import validators as val
 from statham.dsl.elements.base import Element
 from statham.dsl.constants import Maybe, NotPassed
+from statham.dsl.validation import InstanceOf
 
 
 Item = TypeVar("Item")
@@ -19,6 +19,8 @@ class Array(Element[List[Item]]):
     # TODO: contains
     """
 
+    items: Element[Item]
+
     def __init__(
         self,
         items: Element[Item],
@@ -42,16 +44,7 @@ class Array(Element[List[Item]]):
 
     @property
     def type_validator(self):
-        return val.instance_of(list)
-
-    @property
-    def validators(self):
-        validators = super().validators
-        if not isinstance(self.minItems, NotPassed):
-            validators.append(val.min_items(self.minItems))
-        if not isinstance(self.maxItems, NotPassed):
-            validators.append(val.max_items(self.maxItems))
-        return validators
+        return InstanceOf(list)
 
     def construct(self, value, property_):
         return [
