@@ -15,7 +15,12 @@ from typing import (
 
 from statham.dsl.constants import NotPassed, Maybe
 from statham.dsl.helpers import custom_repr
-from statham.dsl.validation import get_validators, InstanceOf, Validator
+from statham.dsl.validation import (
+    get_validators,
+    InstanceOf,
+    NoMatch,
+    Validator,
+)
 
 
 T = TypeVar("T")
@@ -150,6 +155,24 @@ class Element(Generic[T]):
         return self.construct(value, property_)
 
 
+class Nothing(Element):
+    """Element which matches nothing. Equivalent to False."""
+
+    def __init__(self):
+        super().__init__()  # Don't allow args to Nothing.
+
+    def __bool__(self):
+        return False
+
+    @property
+    def annotation(self) -> str:
+        return "None"
+
+    @property
+    def validators(self) -> List[Validator]:
+        return [NoMatch()]
+
+
 # Needs to be imported last to prevent cyclic import.
 # pylint: disable=wrong-import-position
 from statham.dsl.property import _Property, UNBOUND_PROPERTY
@@ -182,14 +205,17 @@ def object_constructor(
         lambda: default_prop
     )
     if not isinstance(properties, NotPassed):
-        default_properties.update(properties)
+        default_properties.update(
+            {prop.source or key: prop for key, prop in properties.items()}
+        )
 
     def _constructor(value: Any) -> Any:
         if not isinstance(value, dict):
             return value
         return _AnonymousObject(
             {
-                key: default_properties[key](sub_value)
+                default_properties[key].name
+                or key: default_properties[key](sub_value)
                 for key, sub_value in value.items()
             }
         )
