@@ -1,6 +1,6 @@
-from statham.dsl import validators as val
 from statham.dsl.elements.base import Element
 from statham.dsl.constants import Maybe, NotPassed
+from statham.dsl.validation import InstanceOf
 
 
 class Null(Element[None]):
@@ -15,4 +15,4 @@ class Null(Element[None]):
 
     @property
     def type_validator(self):
-        return val.instance_of(type(None))
+        return InstanceOf(type(None))
