@@ -6,7 +6,11 @@ import string
 from typing import Any, Callable, DefaultDict, Dict, List, Type, Union
 import unicodedata
 
-from statham.dsl.constants import COMPOSITION_KEYWORDS, NotPassed
+from statham.dsl.constants import (
+    COMPOSITION_KEYWORDS,
+    NotPassed,
+    UNSUPPORTED_SCHEMA_KEYWORDS,
+)
 from statham.dsl.elements import (
     AllOf,
     AnyOf,
@@ -14,6 +18,7 @@ from statham.dsl.elements import (
     Boolean,
     CompositionElement,
     Integer,
+    Nothing,
     Null,
     Number,
     Object,
@@ -79,7 +84,7 @@ def parse(schema: Dict[str, Any]) -> List[Element]:
     return [parse_element(schema, state)] + [
         parse_element(definition, state)
         for definition in schema.get("definitions", {}).values()
-        if isinstance(definition, (dict, Element))
+        if isinstance(definition, (dict, bool, Element))
     ]
 
 
@@ -88,11 +93,19 @@ def parse(schema: Dict[str, Any]) -> List[Element]:
     SchemaParseError,
     "Could not parse cyclical dependencies of this schema.",
 )
-def parse_element(schema: Dict[str, Any], state: ParseState = None) -> Element:
+def parse_element(
+    schema: Union[bool, Dict[str, Any]], state: ParseState = None
+) -> Element:
     """Parse a JSONSchema element to a DSL Element object."""
+    if isinstance(schema, bool):
+        return Element() if schema else Nothing()
     state = state or ParseState()
     if isinstance(schema, Element):
         return schema
+    if set(schema) & UNSUPPORTED_SCHEMA_KEYWORDS:
+        raise FeatureNotImplementedError.unsupported_keywords(
+            set(schema) & UNSUPPORTED_SCHEMA_KEYWORDS
+        )
     if "properties" in schema:
         schema["properties"] = parse_properties(schema, state)
     if "items" in schema:
@@ -138,10 +151,17 @@ def parse_composition(
             parse_element(sub_schema) for sub_schema in composition.get(key, [])
         ]
     all_of = [base_element] + composition["allOf"]
-    all_of.append(_compose_elements(OneOf, composition["oneOf"]))
-    all_of.append(_compose_elements(AnyOf, composition["anyOf"]))
+    all_of.append(
+        _compose_elements(OneOf, composition["oneOf"], simplify=False)
+    )
+    all_of.append(
+        _compose_elements(AnyOf, composition["anyOf"], simplify=False)
+    )
     element = _compose_elements(AllOf, all_of)
-    element.default = composition.get("default") or element.default
+    default = schema.get("default", NotPassed())
+    if isinstance(element, ObjectMeta):
+        return AllOf(element, default=default)
+    element.default = default or element.default
     return element
 
 
@@ -220,9 +240,11 @@ def parse_object(
     properties = schema.get("properties", {})
     properties.update(
         {
-            key: _Property(Element(), required=True)
+            parse_attribute_name(key): _Property(
+                Element(), required=True, source=key
+            )
             for key in schema.get("required", [])
-            if key not in properties
+            if parse_attribute_name(key) not in properties
         }
     )
     class_dict = ObjectClassDict(
@@ -251,7 +273,7 @@ def parse_properties(
             )
             for key, value in properties.items()
             # Ignore malformed values.
-            if isinstance(value, dict)
+            if isinstance(value, (dict, bool))
         },
         **{
             parse_attribute_name(key): prop
@@ -283,9 +305,10 @@ def parse_attribute_name(name: str) -> str:
     name = "".join(chars).replace(" ", "_").replace("-", "_")
     if not name:
         return "blank"
+    first_chars = set(string.ascii_letters) | {"_"}
     return (
         name
-        if name not in RESERVED_PROPERTIES and name[0].isalpha()
+        if name not in RESERVED_PROPERTIES and name[0] in first_chars
         else f"_{name}"
     )
 
@@ -324,14 +347,16 @@ def parse_items(schema: Dict[str, Any], state: ParseState = None) -> Element:
 
 
 def _compose_elements(
-    element_type: Type[CompositionElement], elements: List[Element]
+    element_type: Type[CompositionElement],
+    elements: List[Element],
+    simplify: bool = True,
 ) -> Element:
     """Create a composition element from a type and list of component elements.
 
     Filters out trivial elements, and simplifies compositions with only one
     composed element.
     """
-    elements = [elem for elem in elements if elem != Element()]
+    elements = [elem for elem in elements if not simplify or elem != Element()]
     if not elements:
         return Element()
     if len(elements) == 1:
